function [Tout, energy_retained, cumul_energy] = compress_tree(T,procento)

% COMPRESS_TREE compresses signal represented by tree T, by retaining just
% PROCENTO percent of the coefficients with highest energy
%
% [Tout, energy_retained, cumul_energy] = COMPRESS_TREE(T,PROCENTO)
%
% in:  T................tree (Wavelet Toolbox object) representing signal
%      PROCENTO.........percentage of coefficients to be retained
%
% out: Tout.............resultant tree (Wavelet Toolbox object)
%      energy_retained..percentage of retained energy
%      cumul_energy.....cumulative energy of ALL wavelet coefficients

% (c)2004 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23


%nacteni vsech koeficientu
cfs = read(T,'data');
%jejich energie
cfs_2 = cfs.^2;
%serazeni podle energie
[cfs_2_sort,ind] = sort(cfs_2);
%celkova energie (dle Parsevala - jen pro ortonorm. wavelety!!!???)
energy = norm(cfs)^2;
%kumulativni energie v koeficientech
cum_cfs_2_sort = cumsum(cfs_2_sort);
%to same normovano na procenta
cumul_energy = cum_cfs_2_sort/energy*100;


%%%% ponechani "procento" nejvetsich koeficientu (zaokrohl. dolu):
%pocet ponechanych
pocet = floor(length(cfs)*procento/100);
%pocet vynulovanych
pocet = length(cfs)-pocet;
%indexy tech, co budou vynulovany
indexy_tech_mensich = ind(1:pocet);
%vynulovani ("prahovani" puvodnich koeficientu)
cfs(indexy_tech_mensich) = 0;  

%%%%%nacteni prahovanych koef. do stromu
%indexy listu
listy = leaves(T);
%rozmery vektoru koeficientu prislusnych k temto listum
sizes = read(T,'sizes',listy);
sizes = sizes(:,2);
%
Tout = T; %kopie vstupniho stromu
%
%zapis vynulovanych koeficientu
start_index = 1;
for count = 1:length(sizes)
    stop_index = start_index + sizes(count)-1;
    Tout = write( Tout, 'cfs', listy(count), cfs(start_index : stop_index) );
    start_index = stop_index+1;
end

%zachovana energie
energy_retained = norm(cfs)^2 /energy*100;