function Tout = denoise_tree(T,thresh_rule,thresh_params)

% DENOISE_TREE denoises signal represented by tree T
% by thresholding the wavelet coefficients
%
% Tout = DENOISE_TREE(T,thresh_rule,thresh_params)
%
% in:  T...............tree (Wavelet Toolbox object) representing
%                      "noisy" signal
%      thresh_rule.....thresholoding rule, see 'thresh.m'
%      thresh_params...thresholoding parameters, see 'thresh.m'
%
% out: Tout.............resultant tree representing the "denoised" signal

% (c)2004 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23


%kopie vstupniho stromu
Tout = T;

%nacteni vsech koeficientu
cfs = read(T,'data');
%zjisteni indexu listu
listy = leaves(T);

%prvni list zleva jsou nejhrubsi aproximace, ty nebudu prahovat
%proto je ulozim uz ted do vysledneho stromu
sizes = read(T,'sizes',listy);
sizes = sizes(:,1);
Tout = write( Tout, 'cfs', listy(1), cfs(1:sizes(1))' );

%dal budu pracovat jen s ostatnimi koeficienty:
cfs = cfs( (sizes(1)+1) : length(cfs) );
%ktere jsou pod prahem?
pod_prahem = (abs(cfs) <= thresh_params{1});
%vynulovat je:
cfs(pod_prahem) = 0;

%zbyle pretvorime dle zvoleneho prahovaciho pravidla:
if ismember({thresh_rule},{'s' 'hy' 'nng'})
    switch thresh_rule
        case 's',  fhandle=@thresh_s;  %soft
        case 'hy', fhandle=@thresh_hy; %hyperbolic
        case 'nng',fhandle=@thresh_nng; %non-negative garrotte
    end
    cfs(~pod_prahem) = feval(fhandle,cfs(~pod_prahem),thresh_params{1});
    
elseif ismember({thresh_rule},{'ss'})
    fhandle = @thresh_ss; %semisoft
    cfs(~pod_prahem) = feval(fhandle,cfs(~pod_prahem),thresh_params{1},thresh_params{2});
end

%%%%%nacteni prahovanych koef. zpet do stromu
%zapis prahovanych koeficientu
start_index = 1;
for count = 2:length(sizes)
    stop_index = start_index + sizes(count)-1;
    Tout = write( Tout, 'cfs', listy(count), cfs(start_index : stop_index)' );
    start_index = stop_index+1;
end