function M_h=era_hard_mean(b,lambda,sigma)

% Exact Risk Analysis - computing mean for the hard thresholding rule
%
% M_h = ERA_HARD_MEAN(B,LAMBDA,SIGMA)
%
% Returns the mean for the hard thresholding rule computed
% for value(s) in B, for the threshold LAMBDA and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, M_h is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2
    error('Too few input arguments.')
elseif nargin==2  %default: computing for SIGMA=1
    square_bracket = 1-normcdf(lambda-b)-normcdf(lambda+b);
    M_h = b+b.*square_bracket + normpdf(lambda-b)-normpdf(lambda+b);
else %user defined SIGMA
    M_h = sigma * era_hard_mean(b./sigma,lambda/sigma);  %calling itself; formula for SIGMA<>1
end