function R_h=era_hard_risk(b,lambda,sigma)

% Exact Risk Analysis - computing risk for the hard thresholding rule
%
% R_h = ERA_HARD_RISK(B,LAMBDA,SIGMA)
%
% Returns the L_2-risk for the hard thresholding rule
% computed for value(s) in B, for the threshold LAMBDA and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, R_h is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2
    error('Too few input arguments.')
elseif nargin==2  %default: computing for SIGMA=1
    square_bracket=normcdf(lambda-b)-normcdf(-lambda-b);
    R_h=1+(b.^2-1).*square_bracket + (lambda+b).*normpdf(lambda+b)+(lambda-b).*normpdf(lambda-b);
else  %user defined SIGMA
    R_h = sigma^2 * era_hard_risk(b./sigma,lambda/sigma);  %calling itself; formula for SIGMA<>1
end