function V_h=era_hard_var(b,lambda,sigma)

% Exact Risk Analysis - computing variance for the hard thresholding rule
%
% V_h = ERA_HARD_VAR(B,LAMBDA,SIGMA)
%
% Returns the variance for the hard thresholding rule computed
% for value(s) in B, for the threshold LAMBDA and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, V_h is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2
    error('Too few input arguments.')
elseif nargin==2  %default: computing for SIGMA=1
    square_bracket=2-normcdf(lambda-b)-normcdf(lambda+b);
    V_h=(b.^2+1).*square_bracket + (lambda+b).*normpdf(lambda-b)+(lambda-b).*normpdf(lambda+b)-era_hard_mean(b,lambda).^2;
else  %user defined SIGMA
    V_h = sigma^2 * era_hard_var(b./sigma,lambda/sigma);  %calling itself; formula for SIGMA<>1
end