function V_hy = era_hy_var(b,lambda,precision_of_num_integration,sigma)

% Exact Risk Analysis - computing variance for the hyperbolic thresholding rule
%
% V_hy = ERA_HY_VAR(B,LAMBDA,PRECISION,SIGMA)
%
% Returns the variance for the hyperbolic thresholding rule computed
% for value(s) in B, for the threshold LAMBDA and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, V_hy is computed using SIGMA=1.
%
% PRECISION........(optional) Because the mean has to be computed numerically,
%                  this parameter must be set; if equal [] or not selected at all,
%                  then it is set defaultly

% (c)2004 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2 %!
    error('Too few input arguments.')
    
elseif nargin < 4  %default: computing for SIGMA=1

    if nargin == 2 %precision_of_num_integration was not specified
        precision_of_num_integration = [];
    end
    
    M_hy = era_hy_mean(b,lambda,precision_of_num_integration);
    V_hy = (lambda+b).*normpdf(lambda-b) + (lambda-b).*normpdf(lambda+b) +...
              (1+b.^2-lambda^2) .* ( 2 - normcdf(lambda+b) - normcdf(lambda-b) ) - M_hy.^2;
    
else  %user defined SIGMA
    V_hy = sigma^2 * era_hy_var(b./sigma,lambda/sigma,precision_of_num_integration);  %calling itself; formula for SIGMA<>1
end