function M_ss = era_semisoft_mean(b,lambda1,lambda2,sigma)

% Exact Risk Analysis - computing mean for the semisoft thresholding rule
%
% M_ss = ERA_SEMISOFT_MEAN(B,LAMBDA,LAMBDA2,SIGMA)
%
% Returns the mean for the semisoft thresholding rule computed
% for value(s) in B, for the thresholds LAMBDA1 < LAMBDA2 and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, M_ss is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<3 %!
    error('Too few input arguments.')
elseif nargin==3  %default: computing for SIGMA=1
    bracket=m_1(lambda1,lambda2,b)-m_1(lambda1,lambda2,-b);
    M_ss = era_hard_mean(b,lambda2) + lambda2/(lambda2-lambda1) * bracket;
else  %user defined SIGMA
    M_ss = sigma * era_semisoft_mean(b./sigma,lambda1/sigma,lambda2/sigma);  %calling itself; formula for SIGMA<>1
end


%***************** sub-functions **********************
function X=m_1(lambda1,lambda2,b)  %assistant function
X=(b-lambda1).*[normcdf(lambda2-b)-normcdf(lambda1-b)] - normpdf(lambda2-b)+ normpdf(lambda1-b);
return