function R_ss = era_semisoft_risk(b,lambda1,lambda2,sigma)

% Exact Risk Analysis - computing risk for the semisoft thresholding rule
%
% R_ss = ERA_SEMISOFT_RISK(B,LAMBDA,LAMBDA2,SIGMA)
%
% Returns the L2-risk for the semisoft thresholding rule computed
% for value(s) in B, for the thresholds LAMBDA1 < LAMBDA2 and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, R_ss is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<3 %!
    error('Too few input arguments.')
elseif nargin==3  %default: computing for SIGMA=1
    square_bracket=normcdf(lambda1-b)-normcdf(-lambda1-b);
    r1=lambda1/(lambda2-lambda1);
    r2=lambda2/(lambda2-lambda1);
    R_ss = (b.^2).*square_bracket - normcdf(lambda2-b) + normcdf(-lambda2-b) +...
        psi(lambda1-b,lambda2-b,r2,r1*(b-lambda2)) +...
        psi(lambda1+b,lambda2+b,r2,-r1*(b+lambda2)) +...
        (lambda2-b).*normpdf(lambda2-b) + (lambda2+b).*normpdf(lambda2+b) +1;
else  %user defined SIGMA
    R_ss = sigma^2 * era_semisoft_risk(b./sigma,lambda1/sigma,lambda2/sigma);  %calling itself; formula for SIGMA<>1
end


%***************** sub-functions **********************
function X=psi(a,b,c,d) %an auxiliary function for computation of L_2-risk of semisoft thresholding
                        %!pozor zde 'b' hraje odlisnou roli
                        %'c' je ve vypoctu vzdy skalar, ostatni muzou byt stejne dlouhe vektory
X = (c^2+d.^2).*(normcdf(b)-normcdf(a)) + c*normpdf(a).*(c*a+2*d) - c*normpdf(b).*(c*b+2*d);
return