function V_ss = era_semisoft_var(b,lambda1,lambda2,sigma)

% Exact Risk Analysis - computing variance for the semisoft thresholding rule
%
% V_ss = ERA_SEMISOFT_VAR(B,LAMBDA,LAMBDA2,SIGMA)
%
% Returns the variance for the semisoft thresholding rule computed
% for value(s) in B, for the thresholds LAMBDA1 < LAMBDA2 and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, V_ss is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<3 %!
    error('Too few input arguments.')
elseif nargin==3  %default: computing for SIGMA=1
    bracket = v_2(lambda1,lambda2,b) + v_2(lambda1,lambda2,-b);
    V_ss =era_hard_var(b,lambda2) - lambda2/(lambda2-lambda1) * bracket;
else  %user defined SIGMA
    V_ss = sigma^2 * era_semisoft_var(b./sigma,lambda1/sigma,lambda2/sigma);  %calling itself; formula for SIGMA<>1
end


%***************** sub-functions **********************
function X=m_1(lambda1,lambda2,b)  %auxiliary function
X=(b-lambda1).* (normcdf(lambda2-b)-normcdf(lambda1-b)) - normpdf(lambda2-b)+ normpdf(lambda1-b);
return

function X=v_2(lambda1,lambda2,b)  %auxiliary function for computing the variance of semisoft thresholding
r=lambda2/(lambda2-lambda1);
bracket = 2*era_hard_mean(b,lambda2) + r* (m_1(lambda1,lambda2,b)-m_1(lambda1,lambda2,-b));
X = m_1(lambda1,lambda2,b) .* bracket - r*m_2(lambda1,lambda2,b);
return

function X=m_2(lambda1,lambda2,b) %auxiliary function
bracket = normcdf(lambda2-b)-normcdf(lambda1-b);
X=(1+(b-lambda1).^2) .* bracket - (lambda2-2*lambda1+b).*normpdf(lambda2-b) - (lambda1-b).*normpdf(lambda1-b);
return