function R_s = era_soft_risk(b,lambda,sigma)

% Exact Risk Analysis - computing risk for the soft thresholding rule
%
% R_s = ERA_SOFT_RISK(B,LAMBDA,SIGMA)
%
% Returns the L_2-risk for the hard thresholding rule
% computed for value(s) in B, for the threshold LAMBDa and for the
% gaussian noise standard deviation, SIGMA. SIGMA is an optional
% parameter; when omitted, R_s is computed using SIGMA=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2
    error('Too few input arguments.')
elseif nargin==2  %default: computing for SIGMA=1
    square_bracket = normcdf(lambda-b)-normcdf(-lambda-b);
    R_s = 1+lambda^2+(b.^2-lambda^2-1).*square_bracket - (lambda-b).*normpdf(lambda+b)-(lambda+b).*normpdf(lambda-b);
else  %user defined SIGMA
    R_s = sigma^2 * era_soft_risk(b./sigma,lambda/sigma);  %calling itself; formula for SIGMA<>1
end