function V_s = era_soft_var(b,lambda,sigma)

% Exact Risk Analysis - computing variance for the soft thresholding rule
%
% V_s = ERA_SOFT_VAR(B,LAMBDA,SIGMA)
%
% Returns the variance for the soft thresholding rule computed
% for value(s) in b, for the threshold lambda and for the
% gaussian noise standard deviation, sigma. Sigma is an optional
% parameter; when omitted, V_s is computed using sigma=1.

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23

if nargin<2
    error('Too few input arguments.')
elseif nargin==2  %default: computing for SIGMA=1
    square_bracket = v_1(lambda,b)+v_1(lambda,-b);
    V_s = era_hard_var(b,lambda) - lambda*square_bracket;
else  %user defined SIGMA
    V_s = sigma^2 * era_soft_var(b./sigma,lambda/sigma);  %calling itself; formula for SIGMA<>1
end


%***************** sub-functions **********************
function X=v_1(lambda,b)  %auxiliary function for computing the variance of soft thresholding
X=(1+normcdf(lambda-b)-normcdf(lambda+b)).*((2*b-lambda).*(1-normcdf(lambda-b))+2*normpdf(lambda-b));
return