function [lambda_opt,crit_value_opt,index_opt]=gcv_h(signal,decomp_depth,wav_name,thresh_depth,lambda_grid,plot_boolean)
% Nalezne optimalni prahovou hodnotu podle kriteria GCV pro tvrde prahovani
%
% [lambda_opt, crit_value_opt, index_opt]=
%        GCV_H(signal, decomp_depth, wav_name, thresh_depth, lambda_grid, plot_boolean)
%
% Vstupni parametry:
% ~~~~~~~~~~~~~~~~~
% signal...........signal, pro ktery chceme nalezt optimalni hodnotu prahu; sloupcovy vektor
% decomp_depth.....hloubka waveletove dekompozice
% wav_name.........jmeno dekompozicniho waveletu; napr. 'db3'
% thresh_depth.....hloubka prahovani
% lambda_grid......sit parametru, v nichz se vyhodnoti kriterium GCV
% plot_boolean.....volitelny logicky parametr; pokud obsahuje nenulovou hodnotu,
%                  vykresli se graf prubehu GCV s vyznacenim optimalni hodnoty.
%                  Pokud parametr neni uveden nebo je nulovy, graf se nevykresli.
%
% Vystupni parametry:
% ~~~~~~~~~~~~~~~~~~
% lambda_opt.......optimalni velikost prahu
% crit_value_opt...hodnota kriteria GCV pro lambda_opt
% index_opt........index pozice 'lambda_opt' ve vektoru 'lambda_grid',
%                  neboli lambda_opt=lambda_grid(index_opt)

% Vola funkci THRESH s ruznymi parametry

% (c)2003 Pavel Rajmic, Brno University of Technology, Czech Republic

if nargin<5
    error('Nedostatecny pocet parametru');
elseif nargin==5
    plot_boolean=0;
elseif ~isnumeric(plot_boolean) | length(plot_boolean)>1
    error('"plot_boolean" musi byt jedna numericka hodnota');
end  %v ostatnich pripadech je plot_boolean jedno cislo
if any(lambda_grid<=0)
    error('Parametr ''lambda_grid'' musi mit kladne slozky!')
end

thresh_rule='h';  %napevno nastaveno

for count=1:length(lambda_grid)
    [signal_thresh,mse,N_thresh]=thresh(signal,decomp_depth,wav_name,thresh_rule,{lambda_grid(count) thresh_depth},0); %THRESH bez grafu
    n=length(signal);  %spravne by 'n' mel byt pocet waveletovych koef., ktery se muze malinko lisit
    %zde mozno vyuzit 'mse', ale neudelam to:
    if sum(N_thresh)==0  %nastalo by deleni nulou
        crit_value(count)=NaN;
    else
        crit_value(count)= sum((signal_thresh-signal).^2) / n / (sum(N_thresh)/n)^2;  %hodnota GCV
    end
end

%Hledani minima
[crit_value_opt,index_opt]=min(crit_value);
lambda_opt=lambda_grid(index_opt);

if plot_boolean
    figure
    plot(lambda_grid,crit_value)
    hold on
    plot(lambda_opt,crit_value_opt,'rs')
end