function signal_denoised = wp_denoise(signal_orig,tree_depth,wav_name,thresh_rule,thresh_params)

% WP_DENOISE performs signal denoising using best basis from wavelet packet
%
% SIGNAL_DENOISED = WP_DENOISE(SIGNAL_ORIG, TREE_DEPTH, WAV_NAME, THRESH_RULE, THRESH_PARAMS)
%
% input parameters:
% ~~~~~~~~~~~~~~~~~
%  SIGNAL_ORIG......input "noisy" signal
%  TREE_DEPTH.......the wavelet packet decomposition depth
%  WAV_NAME.........name of the decomposing wavelet; strin, for example 'db3'
%  THRESH_RULE......abbreviation of the thresholding rule to be used; see 'THRESH.M'
%  THRESH_PARAMS....thresholding parameters; see 'THRESH.M'
%
% output parameter:
% ~~~~~~~~~~~~~~~~~
%  SIGNAL_DENOISED..resultant "denoised" signal
%
% REMARK: For extracting the best basis from the wavelet packet,
% 'threshold' entropy is used with threshold value THRESH_PARAMS{1}

% (c)2004 Pavel Rajmic, Brno University of Technology, Czech Republic
% Last Revision 2004-08-23


%pocatecni uplny strom
T = wpdec(signal_orig,tree_depth,wav_name,'threshold',thresh_params{1});

%nejlepsi strom
Tb = besttree(T);

%prahovani "zasumeleho stromu"
Tb_den = denoise_tree(Tb,thresh_rule,thresh_params);

%rekonstrukce vyprahovaneho stromu
signal_denoised = wprec(Tb_den);